# -*- coding: utf-8 -*-

from threading import local

_user = local()
_session = local()

class CurrentSessionMiddleware(object):
    def process_request(self, request):
        _session.value = request.session

def get_current_session():
    return _session.value if hasattr(_session, 'value') else {}


class CurrentUserMiddleware(object):
    def process_request(self, request):
        _user.value = request.user


def get_current_user():
    return _user.value if hasattr(_user, 'value') else None


def get_current_user_id():
    current_user = get_current_user()
    return current_user.id if current_user else 0



# -*- coding: utf-8 -*-


from django.utils.decorators import method_decorator
from django.contrib.auth.decorators import login_required
from django.views.decorators.cache import never_cache


class LoginDispatchMixin(object):
    @method_decorator(login_required)
    @method_decorator(never_cache)
    def dispatch(self, *args, **kwargs):
        return super(LoginDispatchMixin, self).dispatch(*args, **kwargs)

    pass



from setuptools import find_packages, setup

import account_helper

setup(
    name='django-account-helper',
    version=account_helper.version,
    packages=find_packages(exclude=["tests"]),
    # install_requires=['django'],
    url='https://github.com/9nix00/django-account-helper',
    license='http://opensource.org/licenses/MIT',
    download_url='https://github.com/9nix00/django-account-helper/archive/master.zip',
    include_package_data=True,
    author='wangwenpei',
    author_email='wangwenpei@nextoa.com',
    description='django account helper utils for `django.contrib.auth`',
    keywords='django_account_helper,',
)

